@@ -1,17 +1,19 @@
 import kshell_utilities.kshell_utilities
 from kshell_utilities.general_utilities import create_spin_parity_list
 
-res = kshell_utilities.loadtxt(
-    path = "summary_O19_sdpf-mu.txt",
-    load_and_save_to_file = False
-)[0]
-
-
 def test_spin_parity_list():
     """
     Check that all spin-parity pairs appear in spin_parity_list.
+
+    TODO: Loop over BE2 values too?
     """
-    n_transitions = len(res.transitions[:, 0])
+    res = kshell_utilities.loadtxt(
+        path = "summary_O19_sdpf-mu.txt",
+        load_and_save_to_file = False,
+        old_or_new = "old"
+    )[0]
+    
+    n_transitions = len(res.transitions_BM1[:, 0])
     spins = res.levels[:, 1]
     parities = res.levels[:, 2]
     spin_parity_list = create_spin_parity_list(spins, parities)
@@ -21,8 +23,8 @@ def test_spin_parity_list():
         """
         list.index raises ValueError if x is not in list.
         """
-        spin_initial = int(res.transitions[transition_idx, 3])
-        parity_initial = int(res.transitions[transition_idx, 1])
+        spin_initial = int(res.transitions_BM1[transition_idx, 3])
+        parity_initial = int(res.transitions_BM1[transition_idx, 1])
         index = spin_parity_list.index([spin_initial, parity_initial])
 
         if index not in index_list:
